# Generated by Django 2.0.13 on 2019-12-29 00:20
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("webauthin", "0003_auto_20191228_1750")]

    operations = [
        migrations.AlterModelOptions(
            name="authdata", options={"verbose_name_plural": "auth data"}
        )
    ]
