# Generated by Django 2.0.13 on 2019-12-28 16:05
from django.db import migrations
from django.db import models


class Migration(migrations.Migration):

    dependencies = [("webauthin", "0001_initial")]

    operations = [
        migrations.AddField(
            model_name="authdata",
            name="sign_count",
            field=models.IntegerField(default=0),
        )
    ]
